/**
 * Based on examples in
 *     Head First Object-Oriented Analysis and Design
 *     by Brett D. McLaughlin, Gary Pollice, and David West
 *     O'Reilly, 2007
 *     ISBN 978-0-596-00867-3
 *
 * Ported from Java by
 *     Ronald Mak
 *     Department of Computer Engineering
 *     San Jose State University
 *     San Jose, CA  95192
 */
#include <iostream>
#include <string>
#include "Inventory.h"
#include "Guitar.h"
#include "Builder.h"
#include "Type.h"
#include "Wood.h"

using namespace std;

void initialize_inventory(Inventory *inventory);

int main()
{
    // Set up Rick's guitar inventory.
    Inventory *inventory = new Inventory();
    initialize_inventory(inventory);

    Guitar *what_erin_likes = new Guitar("", 0, Builder::FENDER,
                                         "stratocastor", Type::ELECTRIC,
                                         Wood::ALDER, Wood::ALDER);
    vector<Guitar *> matching_guitars = inventory->search(what_erin_likes);

    if (matching_guitars.size() > 0)
    {
        cout << "Erin, you might like these guitars:" << endl << endl;
        for (Guitar *guitar : matching_guitars)
        {
            cout << guitar->get_builder() << " "
                 << guitar->get_model() << " "
                 << guitar->get_type() << " guitar:\n   "
                 << guitar->get_back_wood() << " back and sides,\n   "
                 << guitar->get_top_wood() << " top.\nYou can have it for only $"
                 << guitar->get_price() << "!" << endl << endl;
        }
    }
    else
    {
        cout << "Sorry, Erin, we have nothing for you.";
    }
}

void initialize_inventory(Inventory *inventory)
{
    inventory->add_guitar("11277", 3999.95, Builder::COLLINGS,
                          "CJ", Type::ACOUSTIC,
                          Wood::INDIAN_ROSEWOOD, Wood::SITKA);
    inventory->add_guitar("V95693", 1499.95, Builder::FENDER,
                          "Stratocastor", Type::ELECTRIC,
                          Wood::ALDER, Wood::ALDER);
    inventory->add_guitar("V9512", 1549.95, Builder::FENDER,
                          "Stratocastor", Type::ELECTRIC,
                          Wood::ALDER, Wood::ALDER);
    inventory->add_guitar("122784", 5495.95, Builder::MARTIN,
                          "D-18", Type::ACOUSTIC,
                          Wood::MAHOGANY, Wood::ADIRONDACK);
    inventory->add_guitar("76531", 6295.95, Builder::MARTIN,
                          "OM-28", Type::ACOUSTIC,
                          Wood::BRAZILIAN_ROSEWOOD, Wood::ADIRONDACK);
    inventory->add_guitar("70108276", 2295.95, Builder::GIBSON,
                          "Les Paul", Type::ELECTRIC,
                          Wood::MAHOGANY, Wood::MAPLE);
    inventory->add_guitar("82765501", 1890.95, Builder::GIBSON,
                          "SG '61 Reissue", Type::ELECTRIC,
                          Wood::MAHOGANY, Wood::MAHOGANY);
    inventory->add_guitar("77023", 6275.95, Builder::MARTIN,
                          "D-28", Type::ACOUSTIC,
                          Wood::BRAZILIAN_ROSEWOOD, Wood::ADIRONDACK);
    inventory->add_guitar("1092", 12995.95, Builder::OLSON,
                          "SJ", Type::ACOUSTIC,
                          Wood::BRAZILIAN_ROSEWOOD, Wood::CEDAR);
    inventory->add_guitar("566-62", 8999.95, Builder::RYAN,
                          "Cathedral", Type::ACOUSTIC,
                          Wood::COCOBOLO, Wood::CEDAR);
    inventory->add_guitar("6 29584", 2100.95, Builder::PRS,
                          "Dave Navarro Signature", Type::ELECTRIC,
                          Wood::MAHOGANY, Wood::MAPLE);
}
